Uses of Class org.openqa.selenium.server.ApplicationRegistry (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.ApplicationRegistry

Packages that use ApplicationRegistry
org.openqa.selenium.server | Provides the core Selenium Server classes.

Uses of ApplicationRegistry in org.openqa.selenium.server

Methods in org.openqa.selenium.server that return ApplicationRegistry
`static ApplicationRegistry` | `ApplicationRegistry.instance()` Return the singleton instance.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.